@@ -19,12 +19,9 @@
 
 //#include <QDebug>
 
-#include <QApplication>
-#include <QFileInfo>
 #include <QTranslator>
 #include <QtSingleApplication>
 #include <QStandardPaths>
-#include <QFileInfo>
 #include <QDir>
 
 #include "mainwindow.h"
@@ -43,7 +40,7 @@ int main(int argc, char *argv[])
     if(!app.isRunning())
     {
         app.setApplicationName(QObject::tr("photoflare"));
-        app.setApplicationVersion(QObject::tr("1.6.2"));
+        app.setApplicationVersion(QObject::tr("1.6.5"));
         app.setOrganizationDomain(QObject::tr("photoflare.io"));
 
         // Setup Default settings
@@ -63,26 +60,26 @@ int main(int argc, char *argv[])
         // Set language based on System locale
         if(SETTINGS->getUserLanguage() == "notset")
         {
-            QString sysLanguage =  QLocale::languageToString(QLocale::system().language());
+            QString sysLanguage =  QLocale::countryToString(QLocale::system().country());
             QString lang;
 
-            if(sysLanguage == "English")
+            if(sysLanguage == "United States")
             {
                 lang = "en";
             }
-            else if(sysLanguage == "French")
+            else if(sysLanguage == "France")
             {
                 lang = "fr";
             }
-            else if(sysLanguage == "German")
+            else if(sysLanguage == "Germany")
             {
                 lang = "de";
             }
-            else if(sysLanguage == "Dutch")
+            else if(sysLanguage == "Netherlands")
             {
                 lang = "nl";
             }
-            else if(sysLanguage == "Chinese")
+            else if(sysLanguage == "China")
             {
                 lang = "zh_CN";
             }
@@ -90,10 +87,22 @@ int main(int argc, char *argv[])
             {
                 lang = "zh_TW";
             }
-            else if(sysLanguage == "Czech")
+            else if(sysLanguage == "Czech Republic")
             {
                 lang = "cs";
             }
+            else if(sysLanguage == "Portugal")
+            {
+                lang = "pt_PT";
+            }
+            else if(sysLanguage == "Brazil")
+            {
+                lang = "pt_BR";
+            }
+            else if(sysLanguage == "Sweden")
+            {
+                lang = "sv";
+            }
             SETTINGS->setUserLanguage(lang);
         }
 
