@@ -20,20 +20,15 @@
 //#include <QDebug>
 
 #include <QClipboard>
-#include <QSettings>
 #include <QFileDialog>
 #include <QMessageBox>
-#include <QMouseEvent>
 #include <QMdiSubWindow>
 #include <QtPrintSupport/QPrinter>
 #include <QtPrintSupport/QPrintDialog>
-#include <QShortcut>
-#include <QDateTime>
 #include <QThread>
 #include <QMimeData>
 #include <QDesktopServices>
 #include <QTimer>
-#include <QStandardPaths>
 #include <QImageReader>
 #include <QInputDialog>
 
@@ -62,13 +57,10 @@
 #include "./toolSettings/erasersettingswidget.h"
 #include "./toolSettings/SmudgeSettingsWidget.h"
 
-#include "managers/ToolManager.h"
 #include "Settings.h"
+#include "managers/ToolManager.h"
 #include "managers/FilterManager.h"
 
-#include "mainwindow.h"
-#include "ui_mainwindow.h"
-
 #include "widgets/PaintWidget.h"
 #include "dialogs/NewDialog.h"
 #include "dialogs/aboutdialog.h"
@@ -85,12 +77,13 @@
 #include "dialogs/plugindialog.h"
 #include "dialogs/checkupdatedialog.h"
 
-#include "workers/BatchProcessWorker.h"
 #include "progress/batchprogress.h"
+#include "workers/BatchProcessWorker.h"
 #include "workers/filterworker.h"
 #include "workers/filterworkermp.h"
 
-#include <omp.h>
+#include "mainwindow.h"
+#include "ui_mainwindow.h"
 
 #define PAINT_BRUSH ToolManager::instance()->paintBrush()
 #define PAINT_BRUSH_ADV ToolManager::instance()->paintBrushAdv()
@@ -108,11 +101,11 @@
 
 namespace
 {
-const QString UNTITLED_TAB_NAME = QObject::tr("Untitled");
+    const QString UNTITLED_TAB_NAME = QObject::tr("Untitled");
 }
 
-MainWindow::MainWindow(QWidget *parent) :
-    QMainWindow(parent),
+MainWindow::MainWindow() :
+    QMainWindow(),
     ui(new Ui::MainWindow)
 {
     ui->setupUi(this);
@@ -134,6 +127,8 @@ MainWindow::MainWindow(QWidget *parent) :
 
     // Setup some other defaults on startup
     setWindowSize();
+
+    // Update recents
     updateRecentFilesMenu();
 }
 
@@ -150,10 +145,6 @@ MainWindow::~MainWindow()
 
 void MainWindow::setupWorkspace()
 {
-    // Set icon theme - WIP
-    //QString theme = "Retro";
-    //applyTheme(theme);
-
     // Add zoom ComboBox
     addZoomCombo();
 
@@ -177,8 +168,10 @@ void MainWindow::setupWorkspace()
     // Center colorBox in tool palette.
     ui->verticalLayout->setAlignment(ui->colorBoxWidget, Qt::AlignCenter);
 
-    // Default the transparent dialog and colour mode
+    // Default the transparent dialog
     transparentDialog = 0;
+
+    // Default the colour mode
     ui->actionRGB_Mode->setChecked(true);
 
     // Remove Qt contextmenu from the toolbars
@@ -262,6 +255,7 @@ void MainWindow::connectTools()
 
     QObject::connect(TEXT_TOOL, SIGNAL(editTextFinished()), this, SLOT(on_TextTool_finished()));
     QObject::connect(TEXT_TOOL, SIGNAL(editText(const QString&,const QFont&, const QColor&)), this, SLOT(onEditText(const QString&,const QFont&, const QColor&)));
+
     QObject::connect(MAGIC_WAND, SIGNAL(selectPrimaryColor(const QPoint&,int,bool)), this, SLOT(onSelectPrimaryColor(const QPoint&,int,bool)));
 
     QObject::connect(SETTINGS, SIGNAL(multiWindowModeChanged(bool)), this, SLOT(onMultiWindowModeChanged(bool)));
@@ -390,14 +384,14 @@ void MainWindow::on_actionNew_triggered()
 void MainWindow::on_actionOpen_triggered()
 {
     const QStringList& fileName = QFileDialog::getOpenFileNames(this, tr("Open File"),
-    SETTINGS->getOpenFolder(), tr("All Files (*);;"
-                                "Image Files (*.png *.jpg *.jpeg *.gif);;"
+    SETTINGS->getOpenFolder(), tr("Image Files (*.png *.jpg *.jpeg *.gif *.tif *.tiff *.bmp *.ico);;"
                                 "PNG(*.png);;"
                                 "JPEG(*.jpg *.jpeg);;"
                                 "GIF(*.gif);;"
                                 "TIFF(*.tif *.tiff);;"
                                 "BMP(*.bmp);;"
-                                "ICO(*.ico)"));
+                                "ICO(*.ico);;"
+                                "All Files (*)"));
 /*
                                 "ARW (*.arw *.srf *.sr2);;"
                                 "BAY (*.bay);;"
@@ -546,13 +540,11 @@ void MainWindow::on_actionSave_As_triggered()
     if (widget)
     {
         // Load default filter by image file name.
-        QString currentFileName;
-        currentFileName = ui->mdiArea->currentSubWindow()->windowTitle();
-
+        QString currentFileName = ui->mdiArea->currentSubWindow()->windowTitle();
         QString suffix = QFileInfo(currentFileName).suffix();
 
+        // Setup file filters
         QStringList filters;
-        //filters << tr("All Files (*)");
         filters << tr("png (*.png)");
         filters << tr("jpg (*.jpg *.jpeg)");
         filters << tr("bmp (*.bmp)");
@@ -575,88 +567,68 @@ void MainWindow::on_actionSave_As_triggered()
         if (defaultFilter.isEmpty() && SETTINGS->getSaveFormatEnabled())
             defaultFilter = filters.at(SETTINGS->getSaveFormat().toInt());
 
+        // Get fileName from the dialog
         QString fileName = QFileDialog::getSaveFileName(this, tr("Save File"),
-                                                        SETTINGS->getSaveFolder(), filters.join(";;"), &defaultFilter);
+            SETTINGS->getSaveFolder(), filters.join(";;"), &defaultFilter);
 
+        // Escape if no fileName
+        if (fileName.isEmpty())
+            return;
+
+        // Set Save path to previously used location
         if(SETTINGS->getPreviouslyOpenedSave() == true)
         {
             QDir d = QFileInfo(fileName).absoluteDir();
             SETTINGS->setSaveFolder(d.absolutePath());
         }
 
-
-        if (fileName.isEmpty())
-            return;
-
         // WORKAROUND: Add the extension to the file name manually.
         QString fileNameSuffix = QFileInfo(fileName).suffix();
-
         if (fileNameSuffix.isEmpty())
         {
-                QStringList list = defaultFilter.split(" (");
-                if (list.count() == 2)
-                {
-                    fileNameSuffix = list.at(0);
-                    fileName += "." + fileNameSuffix;
-                }
+            QStringList list = defaultFilter.split(" (");
+            if (list.count() == 2)
+            {
+                fileNameSuffix = list.at(0);
+                fileName += "." + fileNameSuffix;
+            }
         }
-
+        // Default image quality 100 percent
         int quality = -1;
 
+        // Compression dialog to set the quality
         if(SETTINGS->getCompressionDialogEnabled() && (fileNameSuffix == "jpg" || fileNameSuffix == "jpeg"))
         {
             CompressionDialog dlg;
             dlg.exec();
-            quality = dlg.quality();
 
-            //If dialog Accepted
+            // Dialog Accepted
             if(dlg.enableSaveImage)
             {
-                if (saveImage(fileName,quality))
-                {
-                    PaintWidget *widget = getCurrentPaintWidget();
-                    if (widget)
-                        widget->setImage(QImage(fileName));
-
-                    //Update tab label
-                    ui->mdiArea->currentSubWindow()->setWindowModified(false);
-                    ui->mdiArea->currentSubWindow()->setWindowTitle(fileName + " [*]");
-
-                    //Update image path so the file properties dialog will show all file details
-                    QDir d = QFileInfo(fileName).absoluteDir();
-                    widget->setImagePath(d.absolutePath());
-
-                    SETTINGS->addRecentFile(fileName);
-                    updateRecentFilesMenu();
-                }
-                else
-                    showError(tr("Unable to save image."));
-
+                quality = dlg.quality();
             }
         }
-        //Other file formats
-        else
+        // Save image with the selected quality value
+        if (saveImage(fileName, quality))
         {
-            if (saveImage(fileName,quality))
-            {
-                PaintWidget *widget = getCurrentPaintWidget();
-                if (widget)
-                    widget->setImage(QImage(fileName));
+            PaintWidget *widget = getCurrentPaintWidget();
+            if (widget)
+                widget->setImage(QImage(fileName));
 
-                //Update tab label
-                ui->mdiArea->currentSubWindow()->setWindowModified(false);
-                ui->mdiArea->currentSubWindow()->setWindowTitle(fileName + " [*]");
+            // Update tab label
+            ui->mdiArea->currentSubWindow()->setWindowModified(false);
+            ui->mdiArea->currentSubWindow()->setWindowTitle(fileName + " [*]");
 
-                //Update image path so the file properties dialog will show all file details
-                QDir d = QFileInfo(fileName).absoluteDir();
-                widget->setImagePath(d.absolutePath());
+            // Update image path so the file properties dialog will show all file details
+            QDir d = QFileInfo(fileName).absoluteDir();
+            widget->setImagePath(d.absolutePath());
 
-                SETTINGS->addRecentFile(fileName);
-                updateRecentFilesMenu();
-            }
-            else
-                showError(tr("Unable to save image."));
+            // Update recents
+            SETTINGS->addRecentFile(fileName);
+            updateRecentFilesMenu();
         }
+        else
+            showError(tr("Unable to save image."));
     }
 }
 
@@ -682,7 +654,7 @@ bool MainWindow::saveImage(const QString &fileName, int quality)
 
     PaintWidget *widget = getCurrentPaintWidget();
 
-    return widget ? widget->image().save(fileName,0,quality) : false;
+    return widget ? widget->image().save(fileName,nullptr,quality) : false;
 }
 
 void MainWindow::on_actionClose_triggered()
@@ -706,7 +678,7 @@ void MainWindow::on_actionPrint_triggered()
         if (dialog->exec() == QDialog::Accepted)
         {
             QPainter painter;
-            if (! painter.begin(&printer))
+            if (!painter.begin(&printer))
             {
                 qWarning("Failed to init printer");
                 return;
@@ -800,10 +772,8 @@ void MainWindow::onPaste()
     if (widget)
     {
         QClipboard *clipboard = QApplication::clipboard();
-        widget->setPaintTool(MOUSE_POINTER);
+        on_toolButtonPointer_clicked();
         MOUSE_POINTER->setOverlayImage(clipboard->image());
-        m_toolSelected = "pointer";
-        refreshTools();
     }
     else
     {
@@ -823,13 +793,12 @@ void MainWindow::on_actionPaste_triggered()
 
 void MainWindow::on_actionPaste_as_new_image_triggered()
 {
-    on_actionCopy_triggered();
-    PaintWidget *widget = getCurrentPaintWidget();
+    on_actionCopy_triggered();  
     QClipboard *clipboard = QApplication::clipboard();
     if(clipboard->mimeData()->hasImage())
     {
         addPaintWidget(createPaintWidget(clipboard->image().size(),Qt::white));
-        widget = getCurrentPaintWidget();
+        PaintWidget *widget = getCurrentPaintWidget();
         if (widget)
         {
             widget->setImage(clipboard->image());
@@ -935,7 +904,7 @@ void MainWindow::on_actionImage_Size_triggered()
         return;
 
     NewDialog dialog;
-    dialog.setWindowTitle("Resize Image");
+    dialog.setWindowTitle(tr("Resize Image"));
     dialog.setMode(NewDialog::ResizeImage);
     dialog.setImageSize(widget->image().size());
     if (dialog.exec() == QDialog::Accepted)
@@ -952,8 +921,9 @@ void MainWindow::on_actionCanvas_Size_triggered()
         return;
 
     NewDialog dialog;
-    dialog.setWindowTitle("Resize Canvas");
+    dialog.setWindowTitle(tr("Resize Canvas"));
     dialog.setMode(NewDialog::ResizeCanvas);
+    dialog.setImageSize(widget->image().size());
     if (dialog.exec())
     {
         QImage canvas (dialog.newImageSize(), QImage::Format_ARGB32_Premultiplied);
@@ -1004,7 +974,7 @@ void MainWindow::on_actionAutomatic_Crop_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("trim");
+        applyThreadedFilter("trim");
 }
 
 void MainWindow::on_actionOutside_frame_triggered()
@@ -1039,11 +1009,14 @@ void MainWindow::on_actionTransparent_colour_triggered()
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
     {
+        // Set the previous tool so we can revert back to it after finishing transparent colour operation
+        m_previousToolSelected = m_toolSelected;
+
         origImage = widget->image();
-        emit ui->toolButtonDropper->clicked();
+        on_toolButtonDropper_clicked();
         transparentDialog = new TransparentDialog();
         QObject::connect(transparentDialog, SIGNAL(previewTransparent(QColor,int)), this, SLOT(onPreviewTransparent(QColor,int)));
-        QObject::connect(transparentDialog, SIGNAL(dialogFinished(int)), this, SLOT(onTransparentFinished(int)));
+        QObject::connect(transparentDialog, SIGNAL(dialogFinished(int)), this, SLOT(onTransparentFinished()));
         QObject::connect(transparentDialog, SIGNAL(dialogAccepted()), this, SLOT(onTransparentAccepted()));
         QObject::connect(transparentDialog, SIGNAL(dialogRejected()), this, SLOT(onTransparentRejected()));
         transparentDialog->setColor(widget->image().pixel(0,0));
@@ -1052,10 +1025,12 @@ void MainWindow::on_actionTransparent_colour_triggered()
     }
 }
 
-void MainWindow::onTransparentFinished(int)
+void MainWindow::onTransparentFinished()
 {
     delete transparentDialog;
-    transparentDialog = 0;
+    // Restore previous tool
+    m_toolSelected = m_previousToolSelected;
+    QTimer::singleShot(1000, this, SLOT(refreshTools()));
 }
 
 void MainWindow::onTransparentAccepted()
@@ -1069,14 +1044,14 @@ void MainWindow::onTransparentRejected()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-        widget->setImage(origImage);
+        widget->setImageOriginal(origImage);
 }
 
 void MainWindow::onPreviewTransparent(QColor color, int tolerance)
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-        widget->setImage(FilterManager::instance()->floodFillOpacity(origImage, color, tolerance));
+        widget->setImageOriginal(FilterManager::instance()->floodFillOpacity(origImage, color, tolerance));
 }
 
 void MainWindow::on_TextTool_finished()
@@ -1113,7 +1088,9 @@ void MainWindow::onEditText(const QString& text,const QFont& font, const QColor&
     textDialog dialog(this);
     dialog.editText(text, font, color);
     if(dialog.exec())
+    {
         TEXT_TOOL->setText(dialog.text(), dialog.font(), dialog.color(), dialog.antialias(), dialog.position());
+    }
 }
 
 /*
@@ -1451,7 +1428,9 @@ void MainWindow::on_actionFilterbar_triggered()
         ui->toolBar->hide();
     }
     else
+    {
         ui->toolBar->show();
+    }
 }
 
 void MainWindow::on_actionToolpalette_triggered()
@@ -1461,7 +1440,9 @@ void MainWindow::on_actionToolpalette_triggered()
         ui->dockWidget_palette->hide();
     }
     else
+    {
         ui->dockWidget_palette->show();
+    }
 }
 
 void MainWindow::on_actionShow_grid_triggered()
@@ -1687,7 +1668,7 @@ void MainWindow::on_actionCheck_for_updates_triggered()
 
 void MainWindow::on_actionDonate_triggered()
 {
-    QString link = "http://photoflare.io/donate/";
+    QString link = "https://photoflare.io/donate/";
     QDesktopServices::openUrl(QUrl(link));
 }
 
@@ -2350,20 +2331,17 @@ void MainWindow::addPaintWidget(PaintWidget *widget)
         this->zoomCombo->setItemText(0, QString::number(static_cast<int>(scale*100)).append("%"));
         this->zoomCombo->setCurrentIndex(0);
     });
-
     connect(widget, &PaintWidget::selectionChanged, this, &MainWindow::onSelectionChanged);
-
     addChildWindow(widget);
 }
 
 PaintWidget* MainWindow::getCurrentPaintWidget()
 {
-    PaintWidget *widget = 0;
+    PaintWidget *widget = nullptr;
     if(ui->mdiArea->currentSubWindow())
     {
         widget = static_cast<PaintWidget *>(ui->mdiArea->currentSubWindow()->widget());
     }
-
     return widget;
 }
 
@@ -2393,58 +2371,56 @@ void MainWindow::on_actionBrightplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("brightplus");
+        applyThreadedFilter("brightplus");
 }
 
 void MainWindow::on_actionBrightminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilter("brightminus");
+        applyThreadedFilter("brightminus");
 }
 
 void MainWindow::on_actionContrastplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-
-    applyThreadedFilterMP("contrastplus");
-
+        applyThreadedFilterMP("contrastplus");
 }
 
 void MainWindow::on_actionContrastminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("contrastminus");
+        applyThreadedFilterMP("contrastminus");
 }
 
 void MainWindow::on_actionSaturationplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("saturationplus");
+        applyThreadedFilterMP("saturationplus");
 }
 
 void MainWindow::on_actionSaturationminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("saturationminus");
+        applyThreadedFilterMP("saturationminus");
 }
 
 void MainWindow::on_actionGammaCorrectplus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("gammacorrectplus");
+        applyThreadedFilterMP("gammacorrectplus");
 }
 
 void MainWindow::on_actionGammaCorrectminus_triggered()
 {
     PaintWidget *widget = getCurrentPaintWidget();
     if (widget)
-    applyThreadedFilterMP("gammacorrectminus");
+        applyThreadedFilterMP("gammacorrectminus");
 }
 
 void MainWindow::on_actionGradient_triggered()
@@ -2492,7 +2468,7 @@ void MainWindow::on_actionGradient_triggered()
                     stopPoint.setX(image.width());stopPoint.setY(image.height());
                     break;
                 }
-                widget->setImage(FilterManager::instance()->gradient(image,startPoint,stopPoint,dlg.startColor(),dlg.stopColor()));
+                widget->setImage(FilterManager::instance()->gradient(image, startPoint, stopPoint, dlg.startColor(), dlg.stopColor()));
         }
     }
 }
@@ -2503,20 +2479,6 @@ void MainWindow::on_actionGradient_triggered()
 
 */
 
-void MainWindow::applyTheme(QString theme)
-{
-    if(theme != "Default")
-    {
-        ui->actionNew->setIcon(QIcon("./assets/themes/"+theme+"/toolbar1/new.png"));
-        ui->actionOpen->setIcon(QIcon("./assets/themes/"+theme+"/toolbar1/open.png"));
-        ui->actionSave->setIcon(QIcon("./assets/themes/"+theme+"/toolbar1/save.png"));
-        ui->actionPrint->setIcon(QIcon("./assets/themes/"+theme+"/toolbar1/print.png"));
-        ui->actionUndo->setIcon(QIcon("./assets/themes/"+theme+"/toolbar1/undo.png"));
-        ui->actionRedo->setIcon(QIcon("./assets/themes/"+theme+"/toolbar1/redo.png"));
-        ui->actionRGB_Mode->setIcon(QIcon("./assets/themes/"+theme+"/toolbar1/rgb.png"));
-    }
-}
-
 bool MainWindow::eventFilter(QObject * obj, QEvent * e)
 {
     switch (e->type())
@@ -2530,14 +2492,12 @@ bool MainWindow::eventFilter(QObject * obj, QEvent * e)
                 e->ignore();
                 return true;
             }
-
             subWindow->widget()->deleteLater();
             break;
         }
         default:
             qt_noop();
     }
-
     return QObject::eventFilter(obj, e);
 }
 
