@@ -19,9 +19,7 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
-#include <QSignalMapper>
 #include <QMdiArea>
-#include <QProcess>
 #include <QLabel>
 
 #include "dialogs/batchdialog.h"
@@ -51,7 +49,7 @@ class MainWindow : public QMainWindow
     Q_OBJECT
 
 public:
-    explicit MainWindow(QWidget *parent = 0);
+    explicit MainWindow();
     ~MainWindow();
 
     PaintWidget* getCurrentPaintWidget();
@@ -185,7 +183,7 @@ private slots:
     void on_actionHue_variation_triggered();
     void onHuePreviewChanged(QImage image, bool colorize, QColor color, int degrees);
     void onPreviewTransparent(QColor color, int tolerance);
-    void onTransparentFinished(int);
+    void onTransparentFinished();
     void onTransparentAccepted();
     void onTransparentRejected();
     void on_actionGradient_triggered();
@@ -209,17 +207,11 @@ private slots:
     void on_actionCheck_for_updates_triggered();
 
     void on_show_hotspots_triggered();
-
     void on_actionSelect_all_triggered();
-
     void on_actionColour_Threshold_triggered();
-
     void on_actionClearHistory_triggered();
-
     void on_actionClearClipboard_triggered();
-
     void on_actionDuplicate_triggered();
-
     void on_actionShow_grid_triggered();
 
     QString prepareFile(const QString& fileName);
@@ -244,7 +236,6 @@ private:
     void saveGeometryState();
     void createKeyboardShortcuts();
     void disableUnimplementedActions(bool hide);
-    void applyTheme(QString theme);
     void updateStatusArea(int width, int height);
     void clearStatusArea();
 
